# -*- coding: utf-8 -*-
from Plugins.Plugin import PluginDescriptor
from Screens.Screen import Screen
from enigma import getDesktop
from Screens.MessageBox import MessageBox
from Components.ActionMap import NumberActionMap
from Components.FileList import FileList
from Components.Label import Label
from Components.ConfigList import ConfigList
from Components.config import ConfigSelection
from Components.config import getConfigListEntry
from Components.config import KEY_LEFT
from Components.config import KEY_RIGHT
from Components.Pixmap import Pixmap
from Tools.Directories import fileExists
from Tools.Directories import resolveFilename
from Tools.Directories import SCOPE_CURRENT_SKIN
from Tools.Directories import SCOPE_SKIN_IMAGE
from Tools.LoadPixmap import LoadPixmap
from Components.MenuList import MenuList
from Components.Console import Console
from Tools.HardwareInfo import HardwareInfo
import os

from enigma import eTimer
from enigma import iServiceInformation
from enigma import eListboxPythonMultiContent
from enigma import gFont

from .download import BoxPiratescamdownload
from .uninstall import BoxPiratescamuninstall
from .Helpinfo import bpinfoscreen
from .language import _

VERSION = "v1.9.6-r0"


DEUpdate = []
plugin_path = '/usr/lib/enigma2/python/Plugins/Extensions/BoxPirates_CamManager/'


class Tool:
    def readEmuName(self, emu):
        try:
            f = open('/usr/script/bp-script/' + emu + '_em.sh', 'r')
            for line in f.readlines():
                if line.find('#emuname=') >= 0:
                    f.close()
                    return line.split('=')[1][:-1]
            f.close()
            return emu
        except:
            return 'None'

    def readSrvName(self, srv):
        try:
            f = open('/usr/script/bp-script/' + srv + '_cs.sh', 'r')
            for line in f.readlines():
                if line.find('#srvname=') >= 0:
                    f.close()
                    return line.split('=')[1][:-1]
            f.close()
            return srv
        except:
            return 'None'

    def readEmuActive(self):
        try:
            f = open('/usr/bin/emuactive', 'r')
            line = f.readline()
            f.close()
            return line[:-1]
        except:
            return 'None'

    def readSrvActive(self):
        try:
            f = open('/usr/bin/csactive', 'r')
            line = f.readline()
            f.close()
            return line[:-1]
        except:
            return 'None'


t = Tool()


class ListboxE1(MenuList):
    def __init__(self, list, enableWrapAround = False):
        MenuList.__init__(self, list, enableWrapAround, eListboxPythonMultiContent)
        self.l.font(0, gFont('Regular', 20))
        self.l.font(1, gFont('Regular', 22))
        self.l.itemHeight(36)

def GetSkinPath():
    cur_skin_path = resolveFilename(SCOPE_CURRENT_SKIN, '')
    if cur_skin_path == '/usr/share/enigma2/':
        cur_skin_path = '/usr/share/enigma2/skin_default/'
    return cur_skin_path

def parseEcmInfoLine(line):
    if line.__contains__(':'):
        idx = line.index(':')
        line = line[idx + 1:]
        line = line.replace('\n', '')
        while line.startswith(' '):
            line = line[1:]
        while line.endswith(' '):
            line = line[:-1]
        return line
    else:
        return ''

def parseInfoLine(line):
    if line.__contains__('CaID'):
        idx = line.index('D')
        line = line[idx + 1:]
        line = line.replace('\n', '')
        while line.startswith(' '):
            line = line[1:]
        while line.endswith(' '):
            line = line[:-1]
        return line
    else:
        return ''

def ECMparser():
    def chckIdx(what):
        if 'X' in what:
            idx = what.index('X')
            what = what[idx + 1:]
        return what

    try:
        tmp = open('/tmp/ecm.info', 'r')
        content = tmp.read()
    except:
        content = ''
    lines = content.split('\n')
    system = '..............\n'
    caid = '..............\n'
    provider = '..............\n'
    pid = '..............\n'
    using = '..............\n'
    adress = '..............\n'
    hops = '..............\n'
    share = '..............\n'
    ecmTime = '..............\n'
    coding = '..............\n'
    typecam = '..............\n'
    provid = '..............\n'
    dcw0 = '..............\n'
    dcw1 = '..............\n'
    coding = 'Unknown'
    if content != '':
        typcm = False
        for line in lines:
            if line.startswith('=====') and typecam == '..............\n':
                typecam = 'Mgcamd\n'
                typcm = True
            elif typecam == '..............\n':
                typecam = 'CCcam\n'
            elif typecam == 'CCcam\n' and line.startswith('reader:'):
                typecam = 'OScam\n'
            elif typecam == 'CCcam\n' and line.startswith('FROM:'):
                typecam = 'Camd3\n'
            if line.startswith('CW0:') or line.startswith('cw0:'):
                idx = line.index(':')
                dcw0 = line[idx + 2:] + '\n'
            if line.startswith('CW1') or line.startswith('cw1:'):
                idx = line.index(':')
                dcw1 = line[idx + 2:] + '\n'
            if line.startswith('system:') or line.startswith('===='):
                if line.startswith('===='):
                    system = str(line.split(' ')[1].split())
                    system = system[2:-2] + ' ECM' + '\n'
                else:
                    system = parseEcmInfoLine(line) + '\n'
                if len(system) > 19:
                    system = '%s...' % system[:16]
                    system = system + '\n'
            if line.startswith('caid:') or line.startswith('====') or line.startswith('CAID '):
                if line.startswith('===='):
                    caid = str(parseInfoLine(line)).upper()
                    caid = chckIdx(caid)
                    caid = caid[:4] + '\n'
                elif line.startswith('CAID'):
                    caid = str(line.split(' ')[1].split())
                    caid = caid[2:-2]
                    caid = chckIdx(caid.upper())
                    caid = caid[:4] + '\n'
                else:
                    caid = str(parseEcmInfoLine(line)).upper()
                    caid = chckIdx(caid)
                    if len(caid) == 3:
                        caid = '0%s' % caid
                    caid = caid + '\n'
            if caid.startswith('18'):
                coding = 'Nagravision'
            elif caid.startswith('17'):
                coding = 'Betacrypt'
            elif caid.startswith('01'):
                coding = 'Seca'
            elif caid.startswith('06'):
                coding = 'Irdeto'
            elif caid.startswith('05'):
                coding = 'Viaccess'
            elif caid.startswith('0B'):
                coding = 'Conax'
            elif caid.startswith('0D'):
                coding = 'Cryptoworks'
            elif caid.startswith('4A'):
                if caid == '4AE1\n' or caid == '4AE0\n':
                    coding = 'DRE-crypt'
                elif caid == '4ABF\n':
                    coding = 'DGCrypt'
                elif caid == '4AEE\n':
                    coding = 'Bulcrypt'
                elif caid == '4AFC\n':
                    coding = 'Panaccess'
                else:
                    coding = 'Dreamcrypt'
            elif caid.startswith('09'):
                coding = 'Videoguard'
            elif caid.startswith('55'):
                coding = 'Bulcrypt'
            elif caid.startswith('26'):
                coding = 'Biss'
            elif caid == '5601\n':
                coding = 'Verimatrix'
            elif caid == '2710\n':
                coding = 'Exset'
            if line.startswith('provid:') or line.startswith('CAID ') or line.startswith('SysID'):
                if line.startswith('CAID '):
                    provid = str(line.split(' ')[5].split())
                    provid = provid[2:-2]
                    provid = chckIdx(provid.upper())
                    provid = provid + '\n'
                elif line.startswith('SysID'):
                    provid = str(line.split(' ')[1].split())
                    provid = provid[2:-2]
                    provid = provid.upper() + '\n'
                else:
                    provid = parseEcmInfoLine(line)
                    provid = provid.upper()
                    provid = provid[2:] + '\n'
            elif line.startswith('provider:') or line.startswith('prov: '):
                provider = parseEcmInfoLine(line) + '\n'
                if provider.__contains__('key:'):
                    idx = provider.index('key:')
                    provider = provider[:idx] + '\n'
            if provider.__contains__(','):
                idx = provider.index(',')
                provider = provider[:idx] + '\n'
            if provider.__contains__('0X') or provider.__contains__('0x'):
                provider = chckIdx(provider.upper())
            if len(provider) > 19:
                provider = '%s...' % provider[:16]
                provider = provider + '\n'
            if line.startswith('pid:') or line.startswith('====') or line.startswith('CAID '):
                if line.startswith('===='):
                    pid = str(line.split(' ')[7].split())
                    pid = pid[2:-2]
                elif line.startswith('CAID '):
                    pid = str(line.split(' ')[3].split())
                    pid = pid[2:-3]
                else:
                    pid = parseEcmInfoLine(line)
                pid = chckIdx(pid.upper())
                if len(pid) == 2:
                    pid = '00%s' % pid
                if len(pid) == 3:
                    pid = '0%s' % pid
                pid = pid + '\n'
            if line.startswith('using:') or line.startswith('source:') or line.startswith('reader:') or line.startswith('decode:'):
                if line.startswith('source:'):
                    using = str(line.split(' ')[1].split())
                    using = using[2:-2] + '\n'
                elif line.startswith('decode:'):
                    if typcm:
                        typecam = 'Mgcamd\n'
                    else:
                        typecam = 'Gbox\n'
                    if line.__contains__('slot') or line.__contains__('Local'):
                        using = 'Cardreader\n'
                    elif line.__contains__('Internal'):
                        using = 'Emu\n'
                        typecam = 'Gbox\n'
                    elif line.__contains__('com'):
                        using = parseEcmInfoLine(line) + '\n'
                    else:
                        using = 'Network\n'
                else:
                    using = parseEcmInfoLine(line) + '\n'
                    if using == 'sci\n':
                        using = 'Cardreader\n'
            if line.startswith('address:') or line.startswith('source:') or line.startswith('from:') or line.startswith('FROM:') or line.startswith('decode:'):
                if line.startswith('source: net'):
                    idex = line.index('(')
                    adress = line[idex:]
                    adress = adress.replace('\n', '')
                    adress = str(adress.split(' ')[2].split())
                    adress = adress[2:-3] + '\n'
                    if adress.__contains__('127.0.0.1'):
                        adress = 'Local card\n'
                elif line.startswith('source: emu') or line.startswith('decode:'):
                    adress = '..............\n'
                    if line.startswith('decode:') and not using.__contains__('com'):
                        adress = parseEcmInfoLine(line) + '\n'
                else:
                    adress = parseEcmInfoLine(line) + '\n'
                    if adress == '/dev/sci0\n':
                        if HardwareInfo().get_device_name() == 'dm800se':
                            adress = 'Upper slot \n'
                        else:
                            adress = 'Lower slot \n'
                    elif adress == '/dev/sci1\n':
                        if HardwareInfo().get_device_name() == 'dm800se':
                            adress = 'Lower slot \n'
                        else:
                            adress = 'Upper slot \n'
                    elif adress.__contains__('local'):
                        adress = 'Local slot\n'
                    elif coding == 'Unknown':
                        adress = '..............\n'
            if len(adress) > 19:
                adress = '%s...' % adress[:16]
                adress = adress + '\n'
            if line.startswith('share:') or line.startswith('source:'):
                if line.startswith('source: net'):
                    idex = line.index('(')
                    share = line[idex:]
                    share = share.replace('\n', '')
                    share = str(share.split(' ')[0].split())
                    share = share[3:-2] + '\n'
                elif line.startswith('source: emu'):
                    share = '..............\n'
                else:
                    share = parseEcmInfoLine(line) + '\n'
                if len(share) > 19:
                    share = '%s...' % share[:16]
                    share = share + '\n'
            elif line.startswith('response:') or line.startswith('ecm time:') or line.startswith('Time:(') or line.startswith('Time: (') or line.startswith('1') or line.startswith('2') or line.startswith('3') or line.startswith('4') or line.startswith('5') or line.startswith('6') or line.startswith('7') or line.startswith('8') or line.startswith('9'):
                if line.startswith('ecm time:'):
                    ecmTime = parseEcmInfoLine(line) + '\n'
                elif line.startswith('Time:(') or line.startswith('Time: ('):
                    idex = line.index('(')
                    ecmTime = line[idex + 1:-2] + '\n'
                elif line.startswith('response:'):
                    ecmTime = parseEcmInfoLine(line)
                    if len(ecmTime) == 4:
                        ecmTime = '%s.%s\n' % (ecmTime[0], ecmTime[1:])
                    else:
                        ecmTime = '0.%s\n' % ecmTime
                else:
                    ecmTime = str(line.split(' ')[0].split())
                    ecmTime = '0.%s' % ecmTime[2:-2]
                    ecmTime = ecmTime + '\n'
            if line.startswith('Signature OK') and typecam == 'CCcam\n':
                typecam = 'Mgcamd\n'
            if (line.startswith('Time:(') or line.startswith('Time: (')) and (typecam == 'Mgcamd\n'):
                typecam = 'Mbox\n'
                continue
        if typecam == 'Gbox\n' and using == 'Network\n':
            try:
                f = open('/tmp/share.info', 'r')
                for l in f.readlines():
                    l = l.replace('\n', '').strip().split(' ')
                    if len(l) == 10:
                        if provider[:-1] == parseEcmInfoLine(l[9]) and l[5].startswith(caid[:-1]):
                            adress = l[3] + '\n'
                            if len(adress) > 21:
                                adress = '%s..' % adress[:21]
                                adress = adress + '\n'
                            hops = '%s, %s, %s\n' % (l[6], l[7], l[8])
                            share = '%s, %s\n' % (l[5], l[9])
                            break
                        continue
                f.close()
            except:
                pass
        if provider == 'Unknown\n':
            provider = '..............\n'
    return (typecam, system, caid, provider, provid, pid, using, adress, hops, share, ecmTime, coding, dcw0, dcw1)

screensize = getDesktop(0).size().height()
class cammanager(Screen):
    if screensize == 1080:
        skin = """<screen name="cammanager" position="center,center" size="1480,830" title="BoxPirates-Cam-Manager """ + VERSION + """" >
            <widget name="info_use" position="700,300" zPosition="2" size="700,35" valign="center" halign="center" font="Regular;35" transparent="1" />
            <widget name="config" position="700,400" size="700,300" zPosition="2" transparent="1"  itemHeight="35" />
            <widget name="key_red" position="0,15" size="370,28" font="Regular;25" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
            <eLabel name="button_red" position="0,0" size="370,10" backgroundColor="red" zPosition="1" />
            <widget name="key_green" position="370,15" size="370,28" font="Regular;25" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
            <eLabel name="button_green" position="370,0" size="370,10" backgroundColor="green" zPosition="1" />
            <widget name="key_yellow" position="740,15" size="370,28" font="Regular;25" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
            <eLabel name="button_yellow" position="740,0" size="370,10" backgroundColor="yellow" zPosition="1" />
            <widget name="key_blue" position="1110,15" size="370,28" font="Regular;25" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
            <eLabel name="blue" position="1110,0" size="370,10" backgroundColor="blue" zPosition="1" />
            <widget name="ecmlabels" font="Regular;24" position="80,170" zPosition="2" size="150,390" transparent="1" />
            <widget name="ecmValues" font="Regular;24" position="220,170" zPosition="3" size="390,390" transparent="1" />
            <widget position="0,660" size="370,60" source="session.CurrentService" render="Label" halign="center" font="Regular;24" transparent="1"> <convert type="ServiceName">Name</convert></widget>
            <widget name="picchannel" position="135,700" size="100,60" zPosition="2" alphatest="blend" scale="stretch"/>
            <widget source="session.CurrentService" render="Label" position="370,660" size="370,60" font="Regular;24" halign="center" transparent="1"><convert type="ServiceName">Provider</convert></widget>
            <widget name="picprov" position="505,700" size="370,60" zPosition="2" alphatest="blend" />
            <widget name="sat" position="740,660" size="370,60" font="Regular;24" transparent="1" zPosition="2" halign="center" />
            <widget name="picsat" position="875,700" size="370,60" zPosition="2" alphatest="blend" />
            <widget name="cas" position="1110,660" size="370,60" font="Regular;24" transparent="1" zPosition="2" halign="center" />
            <widget name="piccode" position="1245,700" size="370,60" zPosition="2" alphatest="blend" />
            </screen>"""
    if screensize == 720:
        skin = """<screen name="cammanager" position="center,center" size="1000,570" title="BoxPirates-Cam-Manager """ + VERSION + """" >
             <widget name="info_use" position="525,160" zPosition="2" size="420,24" valign="center" halign="center" font="Regular;22" transparent="1" />
             <widget name="config" position="525,220" size="420,250" zPosition="2" transparent="1"  itemHeight="24" />
             <widget name="key_red" position="0,10" size="250,24" font="Regular;18" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
             <eLabel name="button_red" position="0,0" size="250,8" backgroundColor="red" zPosition="1" />
         <widget name="key_green" position="250,10" size="250,24" font="Regular;18" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
             <eLabel name="button_green" position="250,0" size="250,8" backgroundColor="green" zPosition="1" />
             <widget name="key_yellow" position="500,10" size="250,24" font="Regular;18" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
             <eLabel name="button_yellow" position="500,0" size="250,8" backgroundColor="yellow" zPosition="1" />
             <widget name="key_blue" position="750,10" size="250,24" font="Regular;18" halign="center" foregroundColor="white" zPosition="2" transparent="1" />
         <eLabel name="blue" position="750,0" size="250,8" backgroundColor="blue" zPosition="1" />
             <widget name="ecmlabels" font="Regular;17" position="50,75" zPosition="2" size="100,350" transparent="1" />
             <widget name="ecmValues" font="Regular;17" position="150,75" zPosition="3" size="300,350" transparent="1" />
             <widget position="0,390" size="246,60" source="session.CurrentService" render="Label" font="Regular;22" transparent="1" halign="center" ><convert type="ServiceName">Name</convert></widget>
             <widget name="picchannel" position="75,425" size="100,60" zPosition="2" alphatest="blend" scale="stretch"/>
             <widget source="session.CurrentService" render="Label" position="246,390" size="246,60" font="Regular;22" transparent="1" halign="center" >
             <convert type="ServiceName">Provider</convert></widget>
             <widget name="picprov" position="317,425" size="246,60" zPosition="2" alphatest="blend" />
             <widget name="sat" position="492,390" size="246,60" font="Regular;22" transparent="1" zPosition="2" halign="center" />
             <widget name="picsat" position="568,425" size="246,60" zPosition="2" alphatest="blend" />
             <widget name="cas" position="738,390" size="246,60"  font="Regular;22" transparent="1" zPosition="2" halign="center" />
             <widget name="piccode" position="810,425" size="246,60" zPosition="2" alphatest="blend" />
             </screen>"""

    def __init__(self, session):
        Screen.__init__(self, session)
        self.session = session
        self.list = []
        self['config'] = ConfigList(self.list)
        self['picsat'] = Pixmap()
        self['picprov'] = Pixmap()
        self['picchannel'] = Pixmap()
        self['piccode'] = Pixmap()   
        self['sat'] = Label('Sat')
        self['cas'] = Label('CAS')
        self['key_red'] = Label('Start/Stop/Restart')
        self['key_green'] = Label(_('Download'))
        self['key_yellow'] = Label(_('Uninstall'))
        self['key_blue'] = Label(_('Help/Info'))
        self['info_use'] = Label(_('Use the arrow keys < > selection'))
        self['actions'] = NumberActionMap(['ColorActions', 'CiSelectionActions', 'WizardActions', 'SetupActions'], {'blue': self.Helpinfo, 'right': self.keyRight, 'ok': self.ok_pressed, 'back': self.cancel, 'yellow': self.uninstall, 'green': self.download, 'red': self.ok_pressed, 'left': self.keyLeft}, -1)
        self.activityTimer = eTimer()
        self.console = Console()
        self.ecmTimer = eTimer()
        self.ecmTimer.start(10000, True)
        self.onLayoutFinish.append(self.loadEmuList)
        self['ecmValues'] = Label()
        self['ecmlabels'] = Label('Cam:\nSystem:\nCaid:\nProvider:\nProvID:\nPid:\nDCW0:\nDCW1:\nUsing:\nAddress:\nHops:\nShare:\nEcm Time:')
        self['piccode'] = Pixmap()
        self.runECMTimer = eTimer()
        self.runECMTimer.timeout.get().append(self.readEcmInfo)
        self.onLayoutFinish.append(self.startSearchInfo)

    def exit(self):
        if self.runECMTimer.isActive():
            self.runECMTimer.stop()
        self.close()

    def startInfo(self):
        service = self.session.nav.getCurrentService()
        info = service and service.info()
        if info:
            serviceinfo = service.info()
            self.setPicons()
        else:
            pngname = '/usr/lib/enigma2/python/Plugins/Extensions/Ecmchannel/bp_icons/Fta.png'
            if fileExists(pngname):
                self.picon = []
                self.picon.append(LoadPixmap(pngname))
                self['piccode'].instance.setPixmap(self.picon[0])

    def setPicons(self):
        service = self.session.nav.getCurrentService()
        if service:
            info = service and service.info()
            ref = None
            serviceinfo = service.info()
            provname = self.getServiceInfoValue(info, iServiceInformation.sProvider, ref)
            self.path = 'piconProv'
            if provname.startswith('T-K'):
                sname = 'T-KABEL'
            elif provname == 'T-Systems/MTI':
                sname = 'T-SYSTEMS'
            else:
                sname = provname.upper()
            pngname = self.findPicon(sname)
            if pngname == '':
                pngname = self.findPicon('picon_default')
                if pngname == '':
                    tmp = resolveFilename(SCOPE_CURRENT_SKIN, 'picon_default.png')
                    if fileExists(tmp):
                        pngname = tmp
                    else:
                        pngname = resolveFilename(SCOPE_SKIN_IMAGE, 'skin_default/picon_default.png')
            self.picon = []
            self.picon.append(LoadPixmap(pngname))
            self['picprov'].instance.setPixmap(self.picon[0])
            sname = self.getTunerPiconInfo(service)
            self.path = 'piconSat'
            pngname = self.findPicon(sname)
            if pngname == '':
                pngname = self.findPicon('picon_default')
                if pngname == '':
                    tmp = resolveFilename(SCOPE_CURRENT_SKIN, 'picon_default.png')
                    if fileExists(tmp):
                        pngname = tmp
                    else:
                        pngname = resolveFilename(SCOPE_SKIN_IMAGE, 'skin_default/picon_default.png')
            self.picon = []
            self.picon.append(LoadPixmap(pngname))
            self['picsat'].instance.setPixmap(self.picon[0])
            self.path = 'picon'
            sname = self.getServiceInfoValue(info, iServiceInformation.sServiceref, ref)
            pos = sname.rfind(':')
            if pos != -1:
                sname = sname[:pos].rstrip(':').replace(':', '_')
                pngname = self.findPicon(sname)
                if pngname == '':
                    pngname = self.findPicon('picon_default')
                    if pngname == '':
                        tmp = resolveFilename(SCOPE_CURRENT_SKIN, 'picon_default.png')
                        if fileExists(tmp):
                            pngname = tmp
                        else:
                            pngname = resolveFilename(SCOPE_SKIN_IMAGE, 'skin_default/picon_default.png')
            self.picon = []
            self.picon.append(LoadPixmap(pngname))
            self['picchannel'].instance.setPixmap(self.picon[0])

    def findPicon(self, piconName):
        if fileExists('/etc/picon.conf'):
            try:
                f = open('/etc/picon.conf', 'r')
                content = f.read()
                f.close()
            except:
                content = ''
            contentInfo = content.split('\n')
            if content != '':
                for line in contentInfo:
                    if line.startswith(self.path):
                        if line.__contains__('='):
                            stmp = str(line.split('=')[1].split())
                            pngname = stmp[2:-2] + self.path + '/' + piconName + '.png'
                            if fileExists(pngname):
                                return pngname
                            else:
                                continue
                        else:
                            continue
                else:
                    pass
        searchPaths = ('/usr/share/enigma2/%s/', '/media/usb/%s/', '/media/ba/%s/', '/media/cf/%s/', '/media/sda1/%s/', '/media/sda/%s/')
        for path in searchPaths:
            pngname = path % self.path + piconName + '.png'
            if fileExists(pngname):
                return pngname
        return ''

    def getServiceInfoValue(self, info, what, ref = None):
        v = (ref and info.getInfo(ref, what)) or info.getInfo(what)
        if v != iServiceInformation.resIsString:
            return 'N/A'
        else:
            return (ref and info.getInfoString(ref, what)) or info.getInfoString(what)

    def getTunerPiconInfo(self, service):
        tunerinfo = ''
        feinfo = service and service.frontendInfo()
        if feinfo is not None:
            frontendData = feinfo and feinfo.getAll(True)
            if frontendData is not None and frontendData.get('tuner_type') == 'DVB-S':
                try:
                    orbPic = {3590: '10W', 3592: '08W', 530: '530E', 1560: '1560E', 30: '30E', 1056: '1055E', 40: '40E', 48: '48E', 50: '50E', 1082: '1082E', 70: '70E', 2120: '1480W', 1100: '1100E', 1101: '1100E', 3150: '450W', 600: '600E', 90: '90E', 3170: '430W', 100: '100E', 1131: '1130E', 620: '620E', 2690: '910W', 660: '660E', 160: '160E', 685: '685E', 192: '192E', 705: '705E', 1220: '1220E', 200: '200E', 720: '720E', 210: '210E', 215: '215E', 216: '216E', 2780: '820W', 3300: '300W', 232: '235E', 235: '235E', 750: '750E', 765: '765E', 255: '255E', 260: '260E', 2310: '1290W', 2311: '1290W', 130: '130E', 2830: '770W', 785: '785E', 282: '282E', 3355: '245W', 284: '282E', 285: '285E', 800: '800E', 305: '305E', 3380: '220W', 310: '310E', 2875: '727W', 830: '830E', 328: '328E', 330: '330E', 335: '335E', 850: '852E', 2900: '700W', 2390: '1210W', 2391: '1210W', 3420: '180W', 570: '570E', 315: '315E', 1380: '1380E', 360: '360E', 2410: '1190W', 2412: '1190W', 881: '880E', 3450: '150W', 380: '380E', 3460: '140W', 390: '390E', 400: '400E', 3475: '125W', 917: '915E', 1440: '1440E', 3490: '110W', 420: '420E', 2985: '615W', 2990: '610W', 950: '950E', 951: '951E', 3520: '80W', 450: '450E', 2500: '1100W', 2502: '1100W', 3530: '70W', 3020: '580W', 3550: '50W', 482: '480E', 3045: '555W', 3560: '40W', 1006: '1005E', 3325: '275W', 852: '852E', 3070: '530W'}[frontendData.get('orbital_position', 'None')]
                except:
                    orbPic = 'Unsupported SAT: %s' % str([frontendData.get('orbital_position', 'None')])
                tunerinfo = orbPic
                return tunerinfo
            else:
                return ''
        else:
            return ''

    def startSearchInfo(self):
        service = self.session.nav.getCurrentService()
        info = service and service.info()
        if info:
            serviceinfo = service.info()
            if serviceinfo.getInfo(iServiceInformation.sIsCrypted):
                self.readEcmInfo()
            else:
                self['ecmValues'].setText('..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n')
                self['piccode'].instance.setPixmapFromFile('/usr/lib/enigma2/python/Plugins/Extensions/BoxPirates_CamManager/png/Fta.png')

    def readEcmInfo(self):
        self.runECMTimer.stop()
        typecam, system, caid, provider, provid, pid, using, adress, hops, share, ecmTime, coding, dcw0, dcw1 = ECMparser()
        if using == 'unsupported CAs\n':
            self['ecmValues'].setText('..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n..............\n')
            self['piccode'].instance.setPixmapFromFile('/usr/lib/enigma2/python/Plugins/Extensions/BoxPirates_CamManager/png/Unknown.png')
        else:
            self['ecmValues'].setText(typecam + system + caid + provider + provid + pid + dcw0 + dcw1 + using + adress + hops + share + ecmTime)
            self['piccode'].instance.setPixmapFromFile('/usr/lib/enigma2/python/Plugins/Extensions/BoxPirates_CamManager/png/' + coding + '.png')
        self.runECMTimer.start(5000, True)

    def download(self):
        # added by Murxer(01102021) --> openWithCallback
        self.session.openWithCallback(self.loadEmuList, BoxPiratescamdownload)

    def uninstall(self):
        # added by Murxer(01102021) --> openWithCallback
        self.session.openWithCallback(self.loadEmuList, BoxPiratescamuninstall)

    def Helpinfo(self):
        self.session.open(bpinfoscreen)

    def exit(self):
        self.close(False)

    def loadEmuList(self, callback=None):
        emu = []
        crd = []
        emu.append('None')
        crd.append('None')
        self.emu_list = {}
        self.crd_list = {}
        self.emu_list['None'] = 'None'
        self.crd_list['None'] = 'None'
        emufilelist = FileList('/usr/script/bp-script/', matchingPattern = '_em.sh')
        srvfilelist = FileList('/usr/script/bp-script/', matchingPattern = '_cs.sh')
        for x in emufilelist.getFileList():
            if x[0][1] != True:
                try:
                    # used by openatv >= 7.2
                    emuName = t.readEmuName(x[0][4][:-6])
                    emu.append(emuName)
                    self.emu_list[emuName] = x[0][4][:-6]
                except:
                    # used by openatv < 7.2
                    emuName = t.readEmuName(x[0][0][:-6])
                    emu.append(emuName)
                    self.emu_list[emuName] = x[0][0][:-6]
                continue
        softcam = ConfigSelection(choices = emu, default = t.readEmuName(t.readEmuActive()))
        for x in srvfilelist.getFileList():
            if x[0][1] != True:
                try:
                    # used by openatv >= 7.2
                    srvName = t.readSrvName(x[0][4][:-6])
                    crd.append(srvName)
                    self.crd_list[srvName] = x[0][4][:-6]
                except:
                    # used by openatv < 7.2
                    srvName = t.readSrvName(x[0][0][:-6])
                    crd.append(srvName)
                    self.crd_list[srvName] = x[0][0][:-6]
                continue
        cardserver = ConfigSelection(choices = crd, default = t.readSrvName(t.readSrvActive()))
        del self.list[:]
        txt = _('SoftCam') + ' (%s) :' % str(len(emu) - 1)
        self.list.append(getConfigListEntry(txt, softcam))
        txt = _('CardServer') + ' (%s) :' % str(len(crd) - 1)
        self.list.append(getConfigListEntry(txt, cardserver))
        self['config'].list = self.list
        self['config'].l.setList(self.list)
        self.startInfo()

    def keyLeft(self):
        self['config'].handleKey(KEY_LEFT)

    def keyRight(self):
        self['config'].handleKey(KEY_RIGHT)

    def ok_pressed(self):
        if self['config'].getCurrentIndex() == 0:
            try:
                self.newemu = self.emu_list[self['config'].getCurrent()[1].getText()]
            except:
                self.newemu = 'None'
            self.ss_sc()
        elif self['config'].getCurrentIndex() == 1:
            try:
                self.newsrv = self.crd_list[self['config'].getCurrent()[1].getText()]
            except:
                self.newsrv = 'None'
            self.ss_srv()
        else:
            self.close()

    def cancel(self):
        for f in os.listdir('/tmp/'):
            if f.endswith('.png'):
                print('[cammanager] Cleaning temp picture:', f)
                os.remove('/tmp/' + f)
                continue
        self.close()

    def ss_sc(self):
        self.emuactive = t.readEmuActive()
        if self.emuactive == 'None' and self.newemu == 'None':
            return
        elif self.emuactive != 'None' and self.newemu != 'None' and self.emuactive == self.newemu:
            txt = _('Restarting') + ' %s.' % t.readEmuName(self.emuactive)
            self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
            self.mbox.setTitle(_('Running..'))
            self.execute_sc_restart_once = True
            self.activityTimer.timeout.get().append(self.restart_emu)
            self.activityTimer.start(250, False)
            return
        elif self.emuactive != 'None' and self.newemu != 'None' and self.emuactive != self.newemu:
            txt = _('Stopping') + ' %s ' % t.readEmuName(self.emuactive) + _('and starting') + ' %s.' % t.readEmuName(self.newemu)
            self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
            self.mbox.setTitle(_('Running..'))
            self.execute_sc_restart_once = True
            self.activityTimer.timeout.get().append(self.restart_emu)
            self.activityTimer.start(250, False)
            return
        elif self.emuactive != 'None':
            txt = _('Stopping') + ' %s.' % t.readEmuName(self.emuactive)
            self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
            self.mbox.setTitle(_('Running..'))
            self.execute_sc_stop_once = True
            self.activityTimer.timeout.get().append(self.stop_emu)
            self.activityTimer.start(250, False)
            return
        else:
            if self.newemu != 'None':
                txt = _('Starting') + ' %s.' % t.readEmuName(self.newemu)
                self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
                self.mbox.setTitle(_('Running..'))
                self.execute_sc_start_once = True
                self.activityTimer.timeout.get().append(self.start_emu)
                self.activityTimer.start(250, False)
            return

    def restart_emu(self):
        self.activityTimer.stop()
        if self.execute_sc_restart_once:
            os.system('/usr/script/bp-script/' + self.emuactive + '_em.sh stop')
            os.system('/usr/script/bp-script/' + self.newemu + '_em.sh start')
            os.system('echo ' + self.newemu + ' > /usr/bin/emuactive')
        self.execute_sc_restart_once = False
        self.mbox.close()

    def stop_emu(self):
        self.activityTimer.stop()
        if self.execute_sc_stop_once:
            os.system('/usr/script/bp-script/' + self.emuactive + '_em.sh stop')
            os.system('rm -f /usr/bin/emuactive')
        self.execute_sc_stop_once = False
        self.mbox.close()

    def start_emu(self):
        self.activityTimer.stop()
        if self.execute_sc_start_once:
            os.system('/usr/script/bp-script/' + self.newemu + '_em.sh start')
            os.system('echo ' + self.newemu + ' > /usr/bin/emuactive')
        self.execute_sc_start_once = False
        self.mbox.close()

    def ss_srv(self):
        self.serveractive = t.readSrvActive()
        if self.serveractive == 'None' and self.newsrv == 'None':
            return
        elif self.serveractive != 'None' and self.newsrv != 'None' and self.serveractive == self.newsrv:
            txt = _('Restarting') + ' %s.' % t.readSrvName(self.serveractive)
            self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
            self.mbox.setTitle(_('Running..'))
            self.execute_srv_restart_once = True
            self.activityTimer.timeout.get().append(self.restart_cs)
            self.activityTimer.start(250, False)
            return
        elif self.serveractive != 'None' and self.newsrv != 'None' and self.serveractive != self.newsrv:
            txt = _('Stopping') + ' %s' % t.readSrvName(self.serveractive) + ' ' + _('and starting') + ' %s.' % t.readSrvName(self.newsrv)
            self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
            self.mbox.setTitle(_('Running..'))
            self.execute_srv_restart_once = True
            self.activityTimer.timeout.get().append(self.restart_cs)
            self.activityTimer.start(250, False)
            return
        elif self.serveractive != 'None':
            txt = _('Stopping') + ' %s.' % t.readSrvName(self.serveractive)
            self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
            self.mbox.setTitle(_('Running..'))
            self.execute_srv_stop_once = True
            self.activityTimer.timeout.get().append(self.stop_cs)
            self.activityTimer.start(250, False)
            return
        else:
            if self.newsrv != 'None':
                txt = _('Starting') + '  %s.' % t.readSrvName(self.newsrv)
                self.mbox = self.session.open(MessageBox, txt, MessageBox.TYPE_INFO)
                self.mbox.setTitle(_('Running..'))
                self.execute_srv_start_once = True
                self.activityTimer.timeout.get().append(self.start_cs)
                self.activityTimer.start(250, False)
            return

    def restart_cs(self):
        self.activityTimer.stop()
        if self.execute_srv_restart_once:
            if self.serveractive != 'None':
                os.system('/usr/script/bp-script/' + self.serveractive + '_cs.sh stop')
            if self.newsrv != 'None':
                os.system('/usr/script/bp-script/' + self.newsrv + '_cs.sh start')
                os.system('echo ' + self.newsrv + ' > /usr/bin/csactive')
        self.execute_srv_restart_once = False
        self.mbox.close()

    def stop_cs(self):
        self.activityTimer.stop()
        if self.execute_srv_stop_once:
            if self.serveractive != 'None':
                os.system('/usr/script/bp-script/' + self.serveractive + '_cs.sh stop')
                os.system('rm -f /usr/bin/csactive')
        self.execute_srv_stop_once = False
        self.mbox.close()

    def start_cs(self):
        self.activityTimer.stop()
        if self.execute_srv_start_once:
            if self.newsrv != 'None':
                os.system('/usr/script/bp-script/' + self.newsrv + '_cs.sh start')
                os.system('echo ' + self.newsrv + ' > /usr/bin/csactive')
        self.execute_srv_start_once = False
        self.mbox.close()

def main(session, **kwargs):
    session.open(cammanager)

def Plugins(**kwargs):
    return [PluginDescriptor(description = _('Cams und Configs'), fnc = main, icon = 'BoxPirates.png', name = _('BoxPirates CamManager'), where = PluginDescriptor.WHERE_PLUGINMENU)]

